pm4py.algo.transformation.ocel.split\_ocel.variants package
===========================================================

Submodules
----------

pm4py.algo.transformation.ocel.split\_ocel.variants.connected\_components module
--------------------------------------------------------------------------------

.. automodule:: pm4py.algo.transformation.ocel.split_ocel.variants.connected_components
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.transformation.ocel.split_ocel.variants
   :members:
   :undoc-members:
   :show-inheritance:
